/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2019-12-19
**  Copyright: 2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef STATIONPAIRS_H
#define STATIONPAIRS_H

#include "ArrayCoreDLLExport.h"
#include "StationPair.h"
#include "RingPairs.h"
#include "SPACParameters.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT StationPairs : public VectorList<StationPair>
  {
  public:
    StationPairs(const ArraySelection * array);
    ~StationPairs();

    VectorList<RingPairs> rings(const SPACParameters * param);
    VectorList<RingPairs> rings();
  };

} // namespace ArrayCore

#endif // STATIONPAIRS_H

